@@ -21,6 +21,7 @@ import argparse
 from collections import defaultdict
 from collections import namedtuple
 from collections import OrderedDict
+import html.entities
 import logging
 import mimetypes
 import operator
@@ -76,13 +77,17 @@ class Model(docutils.nodes.GenericNodeVisitor):
         self.speaker = None
         self.memory = None
         self.metadata = []
+        self.escape_table = str.maketrans({
+            v: "&" + k for k, v in html.entities.html5.items()
+            if k.endswith(";") and len(v) == 1
+            and v not in "!\"#'()*+,-..:;=@{}~"
+        })
 
     def __iter__(self):
         for shot in self.shots:
             for item in shot.items:
                 yield shot, item
 
-
     def get_entity(self, ref):
         return next((
             entity
@@ -147,7 +152,9 @@ class Model(docutils.nodes.GenericNodeVisitor):
     def visit_emphasis(self, node):
         text = node.astext()
         self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
-        self.html.append('<em class="text">{0}</em>'.format(text))
+        self.html.append('<em class="text">{0}</em>'.format(
+            text.translate(self.escape_table)
+        ))
 
     def visit_Evaluation(self, node):
         ref, attr = node["arguments"][0].split(".")
@@ -170,7 +177,9 @@ class Model(docutils.nodes.GenericNodeVisitor):
     def visit_literal(self, node):
         text = node.astext()
         self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
-        self.html.append('<pre class="text">{0}</pre>'.format(text))
+        self.html.append('<pre class="text">{0}</pre>'.format(
+            text.translate(self.escape_table)
+        ))
 
     def visit_paragraph(self, node):
         self.text = []
@@ -201,7 +210,10 @@ class Model(docutils.nodes.GenericNodeVisitor):
             ref_uri = node["refuri"]
         text = node.astext()
         self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
-        self.html.append('<a href="{0}">{1}</a>'.format(ref_uri, text))
+        self.html.append('<a href="{0}">{1}</a>'.format(
+            ref_uri,
+            text.translate(self.escape_table)
+        ))
 
     def visit_section(self, node):
         self.section_level += 1
@@ -219,7 +231,9 @@ class Model(docutils.nodes.GenericNodeVisitor):
     def visit_strong(self, node):
         text = node.astext()
         self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
-        self.html.append('<strong class="text">{0}</strong>'.format(text))
+        self.html.append('<strong class="text">{0}</strong>'.format(
+            text.translate(self.escape_table)
+        ))
 
     def visit_substitution_reference(self, node):
         try:
@@ -240,17 +254,23 @@ class Model(docutils.nodes.GenericNodeVisitor):
                         tgt["arguments"][0], relative=False, sep="."
                     )
                     self.text.append(str(obj).strip())
-                    self.html.append(str(obj).strip())
+                    self.html.append(
+                        str(obj).strip().translate(self.escape_table)
+                    )
                 elif getattr(entity, "persona", None) is not None:
                     val = operator.attrgetter(attr)(entity.persona)
                     self.text.append(val.strip())
-                    self.html.append('<span class="ref">{0}</span>'.format(val))
+                    self.html.append('<span class="ref">{0}</span>'.format(
+                        val.translate(self.escape_table)
+                    ))
 
     def visit_Text(self, node):
         if isinstance(node.parent, docutils.nodes.paragraph):
             text = node.astext()
             self.text.append(text.lstrip() if self.text and self.text[-1].endswith(tuple(string.whitespace)) else text)
-            self.html.append('<span class="text">{0}</span>'.format(text))
+            self.html.append('<span class="text">{0}</span>'.format(
+                text.translate(self.escape_table)
+            ))
 
     def visit_title(self, node):
         self.log.debug(self.section_level)
